@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ static void g_mime_stream_mmap_init (GMimeStreamMmap *stream, GMimeStreamMmapCla
 static void g_mime_stream_mmap_finalize (GObject *object);
 
 static ssize_t stream_read (GMimeStream *stream, char *buf, size_t len);
-static ssize_t stream_write (GMimeStream *stream, char *buf, size_t len);
+static ssize_t stream_write (GMimeStream *stream, const char *buf, size_t len);
 static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
@@ -160,7 +160,7 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 }
 
 static ssize_t
-stream_write (GMimeStream *stream, char *buf, size_t len)
+stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	GMimeStreamMmap *mstream = (GMimeStreamMmap *) stream;
 	register char *mapptr;
@@ -348,7 +348,7 @@ g_mime_stream_mmap_new (int fd, int prot, int flags)
 	if (fstat (fd, &st) == -1)
 		return NULL;
 	
-	map = mmap (NULL, st.st_size + getpagesize (), prot, flags, fd, 0);
+	map = mmap (NULL, st.st_size, prot, flags, fd, 0);
 	if (map == MAP_FAILED)
 		return NULL;
 	
@@ -395,7 +395,7 @@ g_mime_stream_mmap_new_with_bounds (int fd, int prot, int flags, off_t start, of
 	} else
 		st.st_size = end /* - start */;
 	
-	map = mmap (NULL, st.st_size + getpagesize (), prot, flags, fd, 0);
+	map = mmap (NULL, st.st_size, prot, flags, fd, 0);
 	if (map == MAP_FAILED)
 		return NULL;
 	
